<h1 align="center">kilroy-module-huggingface</h1>

<div align="center">

kilroy module using Hugging Face models 🤗

[![Multiplatform tests](https://github.com/kilroybot/kilroy-module-huggingface/actions/workflows/test-multiplatform.yml/badge.svg)](https://github.com/kilroybot/kilroy-module-huggingface/actions/workflows/test-multiplatform.yml)
[![Docker tests](https://github.com/kilroybot/kilroy-module-huggingface/actions/workflows/test-docker.yml/badge.svg)](https://github.com/kilroybot/kilroy-module-huggingface/actions/workflows/test-docker.yml)
[![Docs](https://github.com/kilroybot/kilroy-module-huggingface/actions/workflows/docs.yml/badge.svg)](https://github.com/kilroybot/kilroy-module-huggingface/actions/workflows/docs.yml)

</div>

---

## Installing

Using `pip`:

```sh
pip install kilroy-module-huggingface
```
